@@ -2,12 +2,13 @@
 
 import numpy as np
 import sys
-from .test_numpy_setuptools_multi import *
+
+from test_numpy_setuptools.test_numpy_setuptools_multi import *
 
 def func(a, b):
     say_hello(a)
     ret_list(a, b)
-    result = np.sqrt(test_numpy_setuptools_multi.multiplication(int(a), int(b)))
+    result = np.sqrt(multiplication(int(a), int(b)))
     return result
 
 
